"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    maximum_player_session_count: int,
    fleet_id: str = None,
    alias_id: str = None,
    name: str = None,
    game_properties: List = None,
    creator_id: str = None,
    game_session_id: str = None,
    idempotency_token: str = None,
    game_session_data: str = None,
    location: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a multiplayer game session for players in a specific fleet location. This operation prompts an available server process to start a game session and retrieves connection information for the new game session. As an alternative, consider using the GameLift game session placement feature with  with StartGameSessionPlacement, which uses FleetIQ algorithms and queues to optimize the placement process. When creating a game session, you specify exactly where you want to place it and provide a set of game session configuration settings. The fleet must be in ACTIVE status before a game session can be created in it.  This operation can be used in the following ways:    To create a game session on an instance in a fleet's home Region, provide a fleet or alias ID along with your game session configuration.    To create a game session on an instance in a fleet's remote location, provide a fleet or alias ID and a location name, along with your game session configuration.    If successful, a workflow is initiated to start a new game session. A GameSession object is returned containing the game session configuration and status. When the status is ACTIVE, game session connection information is provided and player sessions can be created for the game session. By default, newly created game sessions are open to new players. You can restrict new player access by using UpdateGameSession to change the game session's player session creation policy. Game session logs are retained for all active game sessions for 14 days. To access the logs, call GetGameSessionLogUrl to download the log files.  Available in GameLift Local.   Learn more   Start a game session   Related actions   CreateGameSession | DescribeGameSessions | DescribeGameSessionDetails | SearchGameSessions | UpdateGameSession | GetGameSessionLogUrl | StartGameSessionPlacement | DescribeGameSessionPlacement | StopGameSessionPlacement | All APIs by task

    Args:
        fleet_id(str, optional): A unique identifier for the fleet to create a game session in. You can use either the fleet ID or ARN value. Each request must reference either a fleet ID or alias ID, but not both. Defaults to None.
        alias_id(str, optional): A unique identifier for the alias associated with the fleet to create a game session in. You can use either the alias ID or ARN value. Each request must reference either a fleet ID or alias ID, but not both. Defaults to None.
        maximum_player_session_count(int): The maximum number of players that can be connected simultaneously to the game session.
        name(str, optional): A descriptive label that is associated with a game session. Session names do not need to be unique. Defaults to None.
        game_properties(List, optional): A set of custom properties for a game session, formatted as key:value pairs. These properties are passed to a game server process in the GameSession object with a request to start a new game session. Defaults to None.
        creator_id(str, optional): A unique identifier for a player or entity creating the game session. This parameter is required when requesting a new game session on a fleet with a resource creation limit policy. This type of policy limits the number of concurrent active game sessions that one player can create within a certain time span. GameLift uses the CreatorId to evaluate the new request against the policy. Defaults to None.
        game_session_id(str, optional):  This parameter is no longer preferred. Please use IdempotencyToken instead. Custom string that uniquely identifies a request for a new game session. Maximum token length is 48 characters. If provided, this string is included in the new game session's ID. Defaults to None.
        idempotency_token(str, optional): Custom string that uniquely identifies the new game session request. This is useful for ensuring that game session requests with the same idempotency token are processed only once. Subsequent requests with the same string return the original GameSession object, with an updated status. Maximum token length is 48 characters. If provided, this string is included in the new game session's ID. A game session ARN has the following format: arn:aws:gamelift:<region>::gamesession/<fleet ID>/<custom ID string or idempotency token>. Idempotency tokens remain in use for 30 days after a game session has ended; game session objects are retained for this time period and then deleted. Defaults to None.
        game_session_data(str, optional): A set of custom game session properties, formatted as a single string value. This data is passed to a game server process in the GameSession object with a request to start a new game session. Defaults to None.
        location(str, optional): A fleet's remote location to place the new game session in. If this parameter is not set, the new game session is placed in the fleet's home Region. Specify a remote location with an AWS Region code such as us-west-2. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.session.init.create(
                ctx, maximum_player_session_count=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.session.init.create maximum_player_session_count=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="create_game_session",
        op_kwargs={
            "FleetId": fleet_id,
            "AliasId": alias_id,
            "MaximumPlayerSessionCount": maximum_player_session_count,
            "Name": name,
            "GameProperties": game_properties,
            "CreatorId": creator_id,
            "GameSessionId": game_session_id,
            "IdempotencyToken": idempotency_token,
            "GameSessionData": game_session_data,
            "Location": location,
        },
    )


async def describe_all(
    hub,
    ctx,
    fleet_id: str = None,
    game_session_id: str = None,
    alias_id: str = None,
    location: str = None,
    status_filter: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a set of one or more game sessions in a specific fleet location. You can optionally filter the results by current game session status. Alternatively, use SearchGameSessions to request a set of active game sessions that are filtered by certain criteria. To retrieve the protection policy for game sessions, use DescribeGameSessionDetails. This operation can be used in the following ways:    To retrieve all game sessions that are currently running on all locations in a fleet, provide a fleet or alias ID, with an optional status filter. This approach returns all game sessions in the fleet's home Region and all remote locations.   To retrieve all game sessions that are currently running on a specific fleet location, provide a fleet or alias ID and a location name, with optional status filter. The location can be the fleet's home Region or any remote location.   To retrieve a specific game session, provide the game session ID. This approach looks for the game session ID in all fleets that reside in the AWS Region defined in the request.   Use the pagination parameters to retrieve results as a set of sequential pages.  If successful, a GameSession object is returned for each game session that matches the request.  Available in GameLift Local.   Learn more   Find a game session   Related actions   CreateGameSession | DescribeGameSessions | DescribeGameSessionDetails | SearchGameSessions | UpdateGameSession | GetGameSessionLogUrl | StartGameSessionPlacement | DescribeGameSessionPlacement | StopGameSessionPlacement | All APIs by task

    Args:
        fleet_id(str, optional): A unique identifier for the fleet to retrieve game sessions for. You can use either the fleet ID or ARN value. . Defaults to None.
        game_session_id(str, optional): A unique identifier for the game session to retrieve. . Defaults to None.
        alias_id(str, optional): A unique identifier for the alias associated with the fleet to retrieve game sessions for. You can use either the alias ID or ARN value. Defaults to None.
        location(str, optional): A fleet location to get game session details for. You can specify a fleet's home Region or a remote location. Use the AWS Region code format, such as us-west-2. . Defaults to None.
        status_filter(str, optional): Game session status to filter results on. You can filter on the following states: ACTIVE, TERMINATED, ACTIVATING, and TERMINATING. The last two are transitory and used for only very brief periods of time. . Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.session.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.session.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_game_sessions",
        op_kwargs={
            "FleetId": fleet_id,
            "GameSessionId": game_session_id,
            "AliasId": alias_id,
            "Location": location,
            "StatusFilter": status_filter,
            "Limit": limit,
            "NextToken": next_token,
        },
    )


async def search(
    hub,
    ctx,
    fleet_id: str = None,
    alias_id: str = None,
    location: str = None,
    filter_expression: str = None,
    sort_expression: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves all active game sessions that match a set of search criteria and sorts them into a specified order.  When searching for game sessions, you specify exactly where you want to search and provide a search filter expression, a sort expression, or both. A search request can search only one fleet, but it can search all of a fleet's locations.  This operation can be used in the following ways:    To search all game sessions that are currently running on all locations in a fleet, provide a fleet or alias ID. This approach returns game sessions in the fleet's home Region and all remote locations that fit the search criteria.   To search all game sessions that are currently running on a specific fleet location, provide a fleet or alias ID and a location name. For location, you can specify a fleet's home Region or any remote location.   Use the pagination parameters to retrieve results as a set of sequential pages.  If successful, a GameSession object is returned for each game session that matches the request. Search finds game sessions that are in ACTIVE status only. To retrieve information on game sessions in other statuses, use DescribeGameSessions. You can search or sort by the following game session attributes:    gameSessionId -- A unique identifier for the game session. You can use either a GameSessionId or GameSessionArn value.     gameSessionName -- Name assigned to a game session. This value is set when requesting a new game session with CreateGameSession or updating with UpdateGameSession. Game session names do not need to be unique to a game session.    gameSessionProperties -- Custom data defined in a game session's GameProperty parameter. GameProperty values are stored as key:value pairs; the filter expression must indicate the key and a string to search the data values for. For example, to search for game sessions with custom data containing the key:value pair "gameMode:brawl", specify the following: gameSessionProperties.gameMode = "brawl". All custom data values are searched as strings.    maximumSessions -- Maximum number of player sessions allowed for a game session. This value is set when requesting a new game session with CreateGameSession or updating with UpdateGameSession.    creationTimeMillis -- Value indicating when a game session was created. It is expressed in Unix time as milliseconds.    playerSessionCount -- Number of players currently connected to a game session. This value changes rapidly as players join the session or drop out.    hasAvailablePlayerSessions -- Boolean value indicating whether a game session has reached its maximum number of players. It is highly recommended that all search requests include this filter attribute to optimize search performance and return only sessions that players can join.     Returned values for playerSessionCount and hasAvailablePlayerSessions change quickly as players join sessions and others drop out. Results should be considered a snapshot in time. Be sure to refresh search results often, and handle sessions that fill up before a player can join.    Related actions   CreateGameSession | DescribeGameSessions | DescribeGameSessionDetails | SearchGameSessions | UpdateGameSession | GetGameSessionLogUrl | StartGameSessionPlacement | DescribeGameSessionPlacement | StopGameSessionPlacement | All APIs by task

    Args:
        fleet_id(str, optional): A unique identifier for the fleet to search for active game sessions. You can use either the fleet ID or ARN value. Each request must reference either a fleet ID or alias ID, but not both. Defaults to None.
        alias_id(str, optional): A unique identifier for the alias associated with the fleet to search for active game sessions. You can use either the alias ID or ARN value. Each request must reference either a fleet ID or alias ID, but not both. Defaults to None.
        location(str, optional): A fleet location to search for game sessions. You can specify a fleet's home Region or a remote location. Use the AWS Region code format, such as us-west-2.   . Defaults to None.
        filter_expression(str, optional): String containing the search criteria for the session search. If no filter expression is included, the request returns results for all game sessions in the fleet that are in ACTIVE status. A filter expression can contain one or multiple conditions. Each condition consists of the following:    Operand -- Name of a game session attribute. Valid values are gameSessionName, gameSessionId, gameSessionProperties, maximumSessions, creationTimeMillis, playerSessionCount, hasAvailablePlayerSessions.    Comparator -- Valid comparators are: =, <>, <, >, <=, >=.     Value -- Value to be searched for. Values may be numbers, boolean values (true/false) or strings depending on the operand. String values are case sensitive and must be enclosed in single quotes. Special characters must be escaped. Boolean and string values can only be used with the comparators = and <>. For example, the following filter expression searches on gameSessionName: "FilterExpression": "gameSessionName = 'Matt\\'s Awesome Game 1'".    To chain multiple conditions in a single expression, use the logical keywords AND, OR, and NOT and parentheses as needed. For example: x AND y AND NOT z, NOT (x OR y). Session search evaluates conditions from left to right using the following precedence rules:    =, <>, <, >, <=, >=    Parentheses   NOT   AND   OR   For example, this filter expression retrieves game sessions hosting at least ten players that have an open player slot: "maximumSessions>=10 AND hasAvailablePlayerSessions=true". . Defaults to None.
        sort_expression(str, optional): Instructions on how to sort the search results. If no sort expression is included, the request returns results in random order. A sort expression consists of the following elements:    Operand -- Name of a game session attribute. Valid values are gameSessionName, gameSessionId, gameSessionProperties, maximumSessions, creationTimeMillis, playerSessionCount, hasAvailablePlayerSessions.    Order -- Valid sort orders are ASC (ascending) and DESC (descending).   For example, this sort expression returns the oldest active sessions first: "SortExpression": "creationTimeMillis ASC". Results with a null value for the sort operand are returned at the end of the list. Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. The maximum number of results returned is 20, even if this value is not set or is set higher than 20. . Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.session.init.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.session.init.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="search_game_sessions",
        op_kwargs={
            "FleetId": fleet_id,
            "AliasId": alias_id,
            "Location": location,
            "FilterExpression": filter_expression,
            "SortExpression": sort_expression,
            "Limit": limit,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    game_session_id: str,
    maximum_player_session_count: int = None,
    name: str = None,
    player_session_creation_policy: str = None,
    protection_policy: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the mutable properties of a game session.  To update a game session, specify the game session ID and the values you want to change.  If successful, the updated GameSession object is returned.   Related actions   CreateGameSession | DescribeGameSessions | DescribeGameSessionDetails | SearchGameSessions | UpdateGameSession | GetGameSessionLogUrl | StartGameSessionPlacement | DescribeGameSessionPlacement | StopGameSessionPlacement | All APIs by task

    Args:
        game_session_id(str): A unique identifier for the game session to update. .
        maximum_player_session_count(int, optional): The maximum number of players that can be connected simultaneously to the game session. Defaults to None.
        name(str, optional): A descriptive label that is associated with a game session. Session names do not need to be unique. Defaults to None.
        player_session_creation_policy(str, optional): A policy that determines whether the game session is accepting new players. Defaults to None.
        protection_policy(str, optional): Game session protection policy to apply to this game session only.    NoProtection -- The game session can be terminated during a scale-down event.    FullProtection -- If the game session is in an ACTIVE status, it cannot be terminated during a scale-down event.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.session.init.update(ctx, game_session_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.session.init.update game_session_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="update_game_session",
        op_kwargs={
            "GameSessionId": game_session_id,
            "MaximumPlayerSessionCount": maximum_player_session_count,
            "Name": name,
            "PlayerSessionCreationPolicy": player_session_creation_policy,
            "ProtectionPolicy": protection_policy,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, deployment_id: str = None, target_ids: List = None) -> Dict:
    r"""
    **Autogenerated function**

     Returns an array of one or more targets associated with a deployment. This method works with all compute types and should be used instead of the deprecated BatchGetDeploymentInstances. The maximum number of targets that can be returned is 25.  The type of targets returned depends on the deployment's compute platform or deployment method:     EC2/On-premises: Information about EC2 instance targets.     AWS Lambda: Information about Lambda functions targets.     Amazon ECS: Information about Amazon ECS service targets.     CloudFormation: Information about targets of blue/green deployments initiated by a CloudFormation stack update.

    Args:
        deployment_id(str, optional):  The unique ID of a deployment. . Defaults to None.
        target_ids(List, optional):  The unique IDs of the deployment targets. The compute platform of the deployment determines the type of the targets and their formats. The maximum number of deployment target IDs you can specify is 25.    For deployments that use the EC2/On-premises compute platform, the target IDs are EC2 or on-premises instances IDs, and their target type is instanceTarget.     For deployments that use the AWS Lambda compute platform, the target IDs are the names of Lambda functions, and their target type is instanceTarget.     For deployments that use the Amazon ECS compute platform, the target IDs are pairs of Amazon ECS clusters and services specified using the format <clustername>:<servicename>. Their target type is ecsTarget.     For deployments that are deployed with AWS CloudFormation, the target IDs are CloudFormation stack IDs. Their target type is cloudFormationTarget.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.get.deployment.target.batch(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.get.deployment.target.batch
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="batch_get_deployment_targets",
        op_kwargs={"deploymentId": deployment_id, "targetIds": target_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def delete(
    hub, ctx, api_id: str, request_parameter_key: str, route_id: str
) -> None:
    r"""
    **Autogenerated function**

    Deletes a route request parameter.

    Args:
        api_id(str): The API identifier.
        request_parameter_key(str): The route request parameter key.
        route_id(str): The route ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.route.request_parameter.delete(
                ctx, api_id=value, request_parameter_key=value, route_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.route.request_parameter.delete api_id=value, request_parameter_key=value, route_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="delete_route_request_parameter",
        op_kwargs={
            "ApiId": api_id,
            "RequestParameterKey": request_parameter_key,
            "RouteId": route_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def activate(hub, ctx, user_id: str, authentication_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Activates the specified user. Only active users can access Amazon WorkDocs.

    Args:
        user_id(str): The ID of the user.
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.user.activate(ctx, user_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.user.activate user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="activate_user",
        op_kwargs={"UserId": user_id, "AuthenticationToken": authentication_token},
    )


async def create(
    hub,
    ctx,
    username: str,
    given_name: str,
    surname: str,
    password: str,
    organization_id: str = None,
    email_address: str = None,
    time_zone_id: str = None,
    storage_rule: Dict = None,
    authentication_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a user in a Simple AD or Microsoft AD directory. The status of a newly created user is "ACTIVE". New users can access Amazon WorkDocs.

    Args:
        organization_id(str, optional): The ID of the organization. Defaults to None.
        username(str): The login name of the user.
        email_address(str, optional): The email address of the user. Defaults to None.
        given_name(str): The given name of the user.
        surname(str): The surname of the user.
        password(str): The password of the user.
        time_zone_id(str, optional): The time zone ID of the user. Defaults to None.
        storage_rule(Dict, optional): The amount of storage for the user. Defaults to None.
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.user.create(
                ctx, username=value, given_name=value, surname=value, password=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.user.create username=value, given_name=value, surname=value, password=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="create_user",
        op_kwargs={
            "OrganizationId": organization_id,
            "Username": username,
            "EmailAddress": email_address,
            "GivenName": given_name,
            "Surname": surname,
            "Password": password,
            "TimeZoneId": time_zone_id,
            "StorageRule": storage_rule,
            "AuthenticationToken": authentication_token,
        },
    )


async def deactivate(hub, ctx, user_id: str, authentication_token: str = None) -> None:
    r"""
    **Autogenerated function**

    Deactivates the specified user, which revokes the user's access to Amazon WorkDocs.

    Args:
        user_id(str): The ID of the user.
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.user.deactivate(ctx, user_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.user.deactivate user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="deactivate_user",
        op_kwargs={"UserId": user_id, "AuthenticationToken": authentication_token},
    )


async def delete(hub, ctx, user_id: str, authentication_token: str = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified user from a Simple AD or Microsoft AD directory.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Do not set this field when using administrative API actions, as in accessing the API using AWS credentials. Defaults to None.
        user_id(str): The ID of the user.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.user.delete(ctx, user_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.user.delete user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="delete_user",
        op_kwargs={"AuthenticationToken": authentication_token, "UserId": user_id},
    )


async def describe_all(
    hub,
    ctx,
    authentication_token: str = None,
    organization_id: str = None,
    user_ids: str = None,
    query: str = None,
    include: str = None,
    order: str = None,
    sort: str = None,
    marker: str = None,
    limit: int = None,
    fields: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified users. You can describe all users or filter the results (for example, by status or organization). By default, Amazon WorkDocs returns the first 24 active or pending users. If there are more results, the response includes a marker that you can use to request the next set of results.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        organization_id(str, optional): The ID of the organization. Defaults to None.
        user_ids(str, optional): The IDs of the users. Defaults to None.
        query(str, optional): A query to filter users by user name. Defaults to None.
        include(str, optional): The state of the users. Specify "ALL" to include inactive users. Defaults to None.
        order(str, optional): The order for the results. Defaults to None.
        sort(str, optional): The sorting criteria. Defaults to None.
        marker(str, optional): The marker for the next set of results. (You received this marker from a previous call.). Defaults to None.
        limit(int, optional): The maximum number of items to return. Defaults to None.
        fields(str, optional): A comma-separated list of values. Specify "STORAGE_METADATA" to include the user storage quota and utilization information. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.user.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.user.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="describe_users",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "OrganizationId": organization_id,
            "UserIds": user_ids,
            "Query": query,
            "Include": include,
            "Order": order,
            "Sort": sort,
            "Marker": marker,
            "Limit": limit,
            "Fields": fields,
        },
    )


async def update(
    hub,
    ctx,
    user_id: str,
    authentication_token: str = None,
    given_name: str = None,
    surname: str = None,
    type_: str = None,
    storage_rule: Dict = None,
    time_zone_id: str = None,
    locale: str = None,
    grant_poweruser_privileges: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified attributes of the specified user, and grants or revokes administrative privileges to the Amazon WorkDocs site.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        user_id(str): The ID of the user.
        given_name(str, optional): The given name of the user. Defaults to None.
        surname(str, optional): The surname of the user. Defaults to None.
        type_(str, optional): The type of the user. Defaults to None.
        storage_rule(Dict, optional): The amount of storage for the user. Defaults to None.
        time_zone_id(str, optional): The time zone ID of the user. Defaults to None.
        locale(str, optional): The locale of the user. Defaults to None.
        grant_poweruser_privileges(str, optional): Boolean value to determine whether the user is granted Poweruser privileges. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.user.update(ctx, user_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.user.update user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="update_user",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "UserId": user_id,
            "GivenName": given_name,
            "Surname": surname,
            "Type": type_,
            "StorageRule": storage_rule,
            "TimeZoneId": time_zone_id,
            "Locale": locale,
            "GrantPoweruserPrivileges": grant_poweruser_privileges,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    algorithm_name: str,
    training_specification: Dict,
    algorithm_description: str = None,
    inference_specification: Dict = None,
    validation_specification: Dict = None,
    certify_for_marketplace: bool = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a machine learning algorithm that you can use in Amazon SageMaker and list in the Amazon Web Services Marketplace.

    Args:
        algorithm_name(str): The name of the algorithm.
        algorithm_description(str, optional): A description of the algorithm. Defaults to None.
        training_specification(Dict): Specifies details about training jobs run by this algorithm, including the following:   The Amazon ECR path of the container and the version digest of the algorithm.   The hyperparameters that the algorithm supports.   The instance types that the algorithm supports for training.   Whether the algorithm supports distributed training.   The metrics that the algorithm emits to Amazon CloudWatch.   Which metrics that the algorithm emits can be used as the objective metric for hyperparameter tuning jobs.   The input channels that the algorithm supports for training data. For example, an algorithm might support train, validation, and test channels.  .
        inference_specification(Dict, optional): Specifies details about inference jobs that the algorithm runs, including the following:   The Amazon ECR paths of containers that contain the inference code and model artifacts.   The instance types that the algorithm supports for transform jobs and real-time endpoints used for inference.   The input and output content formats that the algorithm supports for inference.  . Defaults to None.
        validation_specification(Dict, optional): Specifies configurations for one or more training jobs and that Amazon SageMaker runs to test the algorithm's training code and, optionally, one or more batch transform jobs that Amazon SageMaker runs to test the algorithm's inference code. Defaults to None.
        certify_for_marketplace(bool, optional): Whether to certify the algorithm so that it can be listed in Amazon Web Services Marketplace. Defaults to None.
        tags(List, optional): An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.algorithm.create(
                ctx, algorithm_name=value, training_specification=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.algorithm.create algorithm_name=value, training_specification=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_algorithm",
        op_kwargs={
            "AlgorithmName": algorithm_name,
            "AlgorithmDescription": algorithm_description,
            "TrainingSpecification": training_specification,
            "InferenceSpecification": inference_specification,
            "ValidationSpecification": validation_specification,
            "CertifyForMarketplace": certify_for_marketplace,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, algorithm_name: str) -> None:
    r"""
    **Autogenerated function**

    Removes the specified algorithm from your account.

    Args:
        algorithm_name(str): The name of the algorithm to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.algorithm.delete(ctx, algorithm_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.algorithm.delete algorithm_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_algorithm",
        op_kwargs={"AlgorithmName": algorithm_name},
    )


async def describe(hub, ctx, algorithm_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a description of the specified algorithm that is in your account.

    Args:
        algorithm_name(str): The name of the algorithm to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.algorithm.describe(ctx, algorithm_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.algorithm.describe algorithm_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_algorithm",
        op_kwargs={"AlgorithmName": algorithm_name},
    )


async def list_all(
    hub,
    ctx,
    creation_time_after: str = None,
    creation_time_before: str = None,
    max_results: int = None,
    name_contains: str = None,
    next_token: str = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the machine learning algorithms that have been created.

    Args:
        creation_time_after(str, optional): A filter that returns only algorithms created after the specified time (timestamp). Defaults to None.
        creation_time_before(str, optional): A filter that returns only algorithms created before the specified time (timestamp). Defaults to None.
        max_results(int, optional): The maximum number of algorithms to return in the response. Defaults to None.
        name_contains(str, optional): A string in the algorithm name. This filter returns only algorithms whose name contains the specified string. Defaults to None.
        next_token(str, optional): If the response to a previous ListAlgorithms request was truncated, the response includes a NextToken. To retrieve the next set of algorithms, use the token in the next request. Defaults to None.
        sort_by(str, optional): The parameter by which to sort the results. The default is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order for the results. The default is Ascending. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.algorithm.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.algorithm.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_algorithms",
        op_kwargs={
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "MaxResults": max_results,
            "NameContains": name_contains,
            "NextToken": next_token,
            "SortBy": sort_by,
            "SortOrder": sort_order,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    profiling_group_name: str,
    accept: str = None,
    end_time: str = None,
    max_depth: int = None,
    period: str = None,
    start_time: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Gets the aggregated profile of a profiling group for a specified time range. Amazon CodeGuru Profiler collects posted agent profiles for a profiling group into aggregated profiles.   <note> <p> Because aggregated profiles expire over time <code>GetProfile</code> is not idempotent. </p> </note> <p> Specify the time range for the requested aggregated profile using 1 or 2 of the following parameters: <code>startTime</code>, <code>endTime</code>, <code>period</code>. The maximum time range allowed is 7 days. If you specify all 3 parameters, an exception is thrown. If you specify only <code>period</code>, the latest aggregated profile is returned. </p> <p> Aggregated profiles are available with aggregation periods of 5 minutes, 1 hour, and 1 day, aligned to UTC. The aggregation period of an aggregated profile determines how long it is retained. For more information, see <a href="https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_AggregatedProfileTime.html"> <code>AggregatedProfileTime</code> </a>. The aggregated profile's aggregation period determines how long it is retained by CodeGuru Profiler. </p> <ul> <li> <p> If the aggregation period is 5 minutes, the aggregated profile is retained for 15 days. </p> </li> <li> <p> If the aggregation period is 1 hour, the aggregated profile is retained for 60 days. </p> </li> <li> <p> If the aggregation period is 1 day, the aggregated profile is retained for 3 years. </p> </li> </ul> <p>There are two use cases for calling <code>GetProfile</code>.</p> <ol> <li> <p> If you want to return an aggregated profile that already exists, use <a href="https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ListProfileTimes.html"> <code>ListProfileTimes</code> </a> to view the time ranges of existing aggregated profiles. Use them in a <code>GetProfile</code> request to return a specific, existing aggregated profile. </p> </li> <li> <p> If you want to return an aggregated profile for a time range that doesn't align with an existing aggregated profile, then CodeGuru Profiler makes a best effort to combine existing aggregated profiles from the requested time range and return them as one aggregated profile. </p> <p> If aggregated profiles do not exist for the full time range requested, then aggregated profiles for a smaller time range are returned. For example, if the requested time range is from 00:00 to 00:20, and the existing aggregated profiles are from 00:15 and 00:25, then the aggregated profiles from 00:15 to 00:20 are returned. </p> </li> </ol>

    Args:
        accept(str, optional):  The format of the returned profiling data. The format maps to the Accept and Content-Type headers of the HTTP request. You can specify one of the following: or the default .   <ul> <li> <p> <code>application/json</code> — standard JSON format </p> </li> <li> <p> <code>application/x-amzn-ion</code> — the Amazon Ion data format. For more information, see <a href="http://amzn.github.io/ion-docs/">Amazon Ion</a>. </p> </li> </ul> . Defaults to None.
        end_time(str, optional):  The end time of the requested profile. Specify using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC.   If you specify endTime, then you must also specify period or startTime, but not both. . Defaults to None.
        max_depth(int, optional):  The maximum depth of the stacks in the code that is represented in the aggregated profile. For example, if CodeGuru Profiler finds a method A, which calls method B, which calls method C, which calls method D, then the depth is 4. If the maxDepth is set to 2, then the aggregated profile contains representations of methods A and B. . Defaults to None.
        period(str, optional):  Used with startTime or endTime to specify the time range for the returned aggregated profile. Specify using the ISO 8601 format. For example, P1DT1H1M1S.   <p> To get the latest aggregated profile, specify only <code>period</code>. </p> . Defaults to None.
        profiling_group_name(str): The name of the profiling group to get.
        start_time(str, optional): The start time of the profile to get. Specify using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC.  <p> If you specify <code>startTime</code>, then you must also specify <code>period</code> or <code>endTime</code>, but not both. </p> . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.profile.init.get(
                ctx, profiling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.profile.init.get profiling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="get_profile",
        op_kwargs={
            "accept": accept,
            "endTime": end_time,
            "maxDepth": max_depth,
            "period": period,
            "profilingGroupName": profiling_group_name,
            "startTime": start_time,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    report_arn: str,
    next_token: str = None,
    max_results: int = None,
    sort_order: str = None,
    sort_by: str = None,
    min_line_coverage_percentage: float = None,
    max_line_coverage_percentage: float = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves one or more code coverage reports.

    Args:
        report_arn(str):  The ARN of the report for which test cases are returned. .
        next_token(str, optional): The nextToken value returned from a previous call to DescribeCodeCoverages. This specifies the next item to return. To return the beginning of the list, exclude this parameter. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        sort_order(str, optional): Specifies if the results are sorted in ascending or descending order. Defaults to None.
        sort_by(str, optional): Specifies how the results are sorted. Possible values are:  FILE_PATH  The results are sorted by file path.  LINE_COVERAGE_PERCENTAGE  The results are sorted by the percentage of lines that are covered.  . Defaults to None.
        min_line_coverage_percentage(float, optional): The minimum line coverage percentage to report. Defaults to None.
        max_line_coverage_percentage(float, optional): The maximum line coverage percentage to report. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.code_coverage.describe_all(ctx, report_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.code_coverage.describe_all report_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="describe_code_coverages",
        op_kwargs={
            "reportArn": report_arn,
            "nextToken": next_token,
            "maxResults": max_results,
            "sortOrder": sort_order,
            "sortBy": sort_by,
            "minLineCoveragePercentage": min_line_coverage_percentage,
            "maxLineCoveragePercentage": max_line_coverage_percentage,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(
    hub, ctx, profile_id: str, key_name: str, values: List, domain_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a new key value with a specific profile, such as a Contact Trace Record (CTR) ContactId. A profile object can have a single unique key and any number of additional keys that can be used to identify the profile that it belongs to.

    Args:
        profile_id(str): The unique identifier of a customer profile.
        key_name(str): A searchable identifier of a customer profile.
        values(List): A list of key values.
        domain_name(str): The unique name of the domain.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.key.add(
                ctx, profile_id=value, key_name=value, values=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.key.add profile_id=value, key_name=value, values=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="add_profile_key",
        op_kwargs={
            "ProfileId": profile_id,
            "KeyName": key_name,
            "Values": values,
            "DomainName": domain_name,
        },
    )


async def delete(
    hub, ctx, profile_id: str, key_name: str, values: List, domain_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Removes a searchable key from a customer profile.

    Args:
        profile_id(str): The unique identifier of a customer profile.
        key_name(str): A searchable identifier of a customer profile.
        values(List): A list of key values.
        domain_name(str): The unique name of the domain.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.key.delete(
                ctx, profile_id=value, key_name=value, values=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.key.delete profile_id=value, key_name=value, values=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="delete_profile_key",
        op_kwargs={
            "ProfileId": profile_id,
            "KeyName": key_name,
            "Values": values,
            "DomainName": domain_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def remove(hub, ctx, account_id: str) -> None:
    r"""
    **Autogenerated function**

    Removes the specified account from the organization. The removed account becomes a standalone account that isn't a member of any organization. It's no longer subject to any policies and is responsible for its own bill payments. The organization's management account is no longer charged for any expenses accrued by the member account after it's removed from the organization. This operation can be called only from the organization's management account. Member accounts can remove themselves with LeaveOrganization instead.    You can remove an account from your organization only if the account is configured with the information required to operate as a standalone account. When you create an account in an organization using the AWS Organizations console, API, or CLI commands, the information required of standalone accounts is not automatically collected. For an account that you want to make standalone, you must choose a support plan, provide and verify the required contact information, and provide a current payment method. AWS uses the payment method to charge for any billable (not free tier) AWS activity that occurs while the account isn't attached to an organization. To remove an account that doesn't yet have this information, you must sign in as the member account and follow the steps at  To leave an organization when all required account information has not yet been provided in the AWS Organizations User Guide.    The account that you want to leave must not be a delegated administrator account for any AWS service enabled for your organization. If the account is a delegated administrator, you must first change the delegated administrator account to another account that is remaining in the organization.   After the account leaves the organization, all tags that were attached to the account object in the organization are deleted. AWS accounts outside of an organization do not support tags.

    Args:
        account_id(str): The unique identifier (ID) of the member account that you want to remove from the organization. The regex pattern for an account ID string requires exactly 12 digits.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.account.from_organization.remove(
                ctx, account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.account.from_organization.remove account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="remove_account_from_organization",
        op_kwargs={"AccountId": account_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    auto_scaling_group_name: str,
    min_size: int,
    max_size: int,
    launch_configuration_name: str = None,
    launch_template: Dict = None,
    mixed_instances_policy: Dict = None,
    instance_id: str = None,
    desired_capacity: int = None,
    default_cooldown: int = None,
    availability_zones: List = None,
    load_balancer_names: List = None,
    target_group_ar_ns: List = None,
    health_check_type: str = None,
    health_check_grace_period: int = None,
    placement_group: str = None,
    vpc_zone_identifier: str = None,
    termination_policies: List = None,
    new_instances_protected_from_scale_in: bool = None,
    capacity_rebalance: bool = None,
    lifecycle_hook_specification_list: List = None,
    tags: List = None,
    service_linked_role_arn: str = None,
    max_instance_lifetime: int = None,
    context: str = None,
) -> None:
    r"""
    **Autogenerated function**

     We strongly recommend using a launch template when calling this operation to ensure full functionality for Amazon EC2 Auto Scaling and Amazon EC2.  Creates an Auto Scaling group with the specified name and attributes.  If you exceed your maximum limit of Auto Scaling groups, the call fails. To query this limit, call the DescribeAccountLimits API. For information about updating this limit, see Amazon EC2 Auto Scaling service quotas in the Amazon EC2 Auto Scaling User Guide. For introductory exercises for creating an Auto Scaling group, see Getting started with Amazon EC2 Auto Scaling and Tutorial: Set up a scaled and load-balanced application in the Amazon EC2 Auto Scaling User Guide. For more information, see Auto Scaling groups in the Amazon EC2 Auto Scaling User Guide. Every Auto Scaling group has three size parameters (DesiredCapacity, MaxSize, and MinSize). Usually, you set these sizes based on a specific number of instances. However, if you configure a mixed instances policy that defines weights for the instance types, you must specify these sizes with the same units that you use for weighting instances.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group. This name must be unique per Region per account.
        launch_configuration_name(str, optional): The name of the launch configuration to use to launch instances.  Conditional: You must specify either a launch template (LaunchTemplate or MixedInstancesPolicy) or a launch configuration (LaunchConfigurationName or InstanceId). Defaults to None.
        launch_template(Dict, optional): Parameters used to specify the launch template and version to use to launch instances.  Conditional: You must specify either a launch template (LaunchTemplate or MixedInstancesPolicy) or a launch configuration (LaunchConfigurationName or InstanceId).  The launch template that is specified must be configured for use with an Auto Scaling group. For more information, see Creating a launch template for an Auto Scaling group in the Amazon EC2 Auto Scaling User Guide. . Defaults to None.
        mixed_instances_policy(Dict, optional): An embedded object that specifies a mixed instances policy. The required properties must be specified. If optional properties are unspecified, their default values are used. The policy includes properties that not only define the distribution of On-Demand Instances and Spot Instances, the maximum price to pay for Spot Instances, and how the Auto Scaling group allocates instance types to fulfill On-Demand and Spot capacities, but also the properties that specify the instance configuration information—the launch template and instance types. The policy can also include a weight for each instance type and different launch templates for individual instance types. For more information, see Auto Scaling groups with multiple instance types and purchase options in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        instance_id(str, optional): The ID of the instance used to base the launch configuration on. If specified, Amazon EC2 Auto Scaling uses the configuration values from the specified instance to create a new launch configuration. To get the instance ID, use the Amazon EC2 DescribeInstances API operation. For more information, see Creating an Auto Scaling group using an EC2 instance in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        min_size(int): The minimum size of the group.
        max_size(int): The maximum size of the group.  With a mixed instances policy that uses instance weighting, Amazon EC2 Auto Scaling may need to go above MaxSize to meet your capacity requirements. In this event, Amazon EC2 Auto Scaling will never go above MaxSize by more than your largest instance weight (weights that define how many units each instance contributes to the desired capacity of the group). .
        desired_capacity(int, optional): The desired capacity is the initial capacity of the Auto Scaling group at the time of its creation and the capacity it attempts to maintain. It can scale beyond this capacity if you configure auto scaling. This number must be greater than or equal to the minimum size of the group and less than or equal to the maximum size of the group. If you do not specify a desired capacity, the default is the minimum size of the group. Defaults to None.
        default_cooldown(int, optional): The amount of time, in seconds, after a scaling activity completes before another scaling activity can start. The default value is 300. This setting applies when using simple scaling policies, but not when using other scaling policies or scheduled scaling. For more information, see Scaling cooldowns for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        availability_zones(List, optional): A list of Availability Zones where instances in the Auto Scaling group can be created. This parameter is optional if you specify one or more subnets for VPCZoneIdentifier. Conditional: If your account supports EC2-Classic and VPC, this parameter is required to launch instances into EC2-Classic. Defaults to None.
        load_balancer_names(List, optional): A list of Classic Load Balancers associated with this Auto Scaling group. For Application Load Balancers, Network Load Balancers, and Gateway Load Balancers, specify the TargetGroupARNs property instead. Defaults to None.
        target_group_ar_ns(List, optional): The Amazon Resource Names (ARN) of the target groups to associate with the Auto Scaling group. Instances are registered as targets in a target group, and traffic is routed to the target group. For more information, see Elastic Load Balancing and Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        health_check_type(str, optional): The service to use for the health checks. The valid values are EC2 (default) and ELB. If you configure an Auto Scaling group to use load balancer (ELB) health checks, it considers the instance unhealthy if it fails either the EC2 status checks or the load balancer health checks. For more information, see Health checks for Auto Scaling instances in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        health_check_grace_period(int, optional): The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before checking the health status of an EC2 instance that has come into service. During this time, any health check failures for the instance are ignored. The default value is 0. For more information, see Health check grace period in the Amazon EC2 Auto Scaling User Guide. Conditional: Required if you are adding an ELB health check. Defaults to None.
        placement_group(str, optional): The name of an existing placement group into which to launch your instances, if any. A placement group is a logical grouping of instances within a single Availability Zone. You cannot specify multiple Availability Zones and a placement group. For more information, see Placement Groups in the Amazon EC2 User Guide for Linux Instances. Defaults to None.
        vpc_zone_identifier(str, optional): A comma-separated list of subnet IDs for a virtual private cloud (VPC) where instances in the Auto Scaling group can be created. If you specify VPCZoneIdentifier with AvailabilityZones, the subnets that you specify for this parameter must reside in those Availability Zones. Conditional: If your account supports EC2-Classic and VPC, this parameter is required to launch instances into a VPC. Defaults to None.
        termination_policies(List, optional): A policy or a list of policies that are used to select the instance to terminate. These policies are executed in the order that you list them. For more information, see Controlling which Auto Scaling instances terminate during scale in in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        new_instances_protected_from_scale_in(bool, optional): Indicates whether newly launched instances are protected from termination by Amazon EC2 Auto Scaling when scaling in. For more information about preventing instances from terminating on scale in, see Instance scale-in protection in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        capacity_rebalance(bool, optional): Indicates whether Capacity Rebalancing is enabled. Otherwise, Capacity Rebalancing is disabled. When you turn on Capacity Rebalancing, Amazon EC2 Auto Scaling attempts to launch a Spot Instance whenever Amazon EC2 notifies that a Spot Instance is at an elevated risk of interruption. After launching a new instance, it then terminates an old instance. For more information, see Amazon EC2 Auto Scaling Capacity Rebalancing in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        lifecycle_hook_specification_list(List, optional): One or more lifecycle hooks for the group, which specify actions to perform when Amazon EC2 Auto Scaling launches or terminates instances. Defaults to None.
        tags(List, optional): One or more tags. You can tag your Auto Scaling group and propagate the tags to the Amazon EC2 instances it launches. Tags are not propagated to Amazon EBS volumes. To add tags to Amazon EBS volumes, specify the tags in a launch template but use caution. If the launch template specifies an instance tag with a key that is also specified for the Auto Scaling group, Amazon EC2 Auto Scaling overrides the value of that instance tag with the value specified by the Auto Scaling group. For more information, see Tagging Auto Scaling groups and instances in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        service_linked_role_arn(str, optional): The Amazon Resource Name (ARN) of the service-linked role that the Auto Scaling group uses to call other Amazon Web Services on your behalf. By default, Amazon EC2 Auto Scaling uses a service-linked role named AWSServiceRoleForAutoScaling, which it creates if it does not exist. For more information, see Service-linked roles in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        max_instance_lifetime(int, optional): The maximum amount of time, in seconds, that an instance can be in service. The default is null. If specified, the value must be either 0 or a number equal to or greater than 86,400 seconds (1 day). For more information, see Replacing Auto Scaling instances based on maximum instance lifetime in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        context(str, optional): Reserved. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.auto_scaling.group.create(
                ctx, auto_scaling_group_name=value, min_size=value, max_size=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.auto_scaling.group.create auto_scaling_group_name=value, min_size=value, max_size=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="create_auto_scaling_group",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "LaunchConfigurationName": launch_configuration_name,
            "LaunchTemplate": launch_template,
            "MixedInstancesPolicy": mixed_instances_policy,
            "InstanceId": instance_id,
            "MinSize": min_size,
            "MaxSize": max_size,
            "DesiredCapacity": desired_capacity,
            "DefaultCooldown": default_cooldown,
            "AvailabilityZones": availability_zones,
            "LoadBalancerNames": load_balancer_names,
            "TargetGroupARNs": target_group_ar_ns,
            "HealthCheckType": health_check_type,
            "HealthCheckGracePeriod": health_check_grace_period,
            "PlacementGroup": placement_group,
            "VPCZoneIdentifier": vpc_zone_identifier,
            "TerminationPolicies": termination_policies,
            "NewInstancesProtectedFromScaleIn": new_instances_protected_from_scale_in,
            "CapacityRebalance": capacity_rebalance,
            "LifecycleHookSpecificationList": lifecycle_hook_specification_list,
            "Tags": tags,
            "ServiceLinkedRoleARN": service_linked_role_arn,
            "MaxInstanceLifetime": max_instance_lifetime,
            "Context": context,
        },
    )


async def delete(
    hub, ctx, auto_scaling_group_name: str, force_delete: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified Auto Scaling group. If the group has instances or scaling activities in progress, you must specify the option to force the deletion in order for it to succeed. If the group has policies, deleting the group deletes the policies, the underlying alarm actions, and any alarm that no longer has an associated action. To remove instances from the Auto Scaling group before deleting it, call the DetachInstances API with the list of instances and the option to decrement the desired capacity. This ensures that Amazon EC2 Auto Scaling does not launch replacement instances. To terminate all instances before deleting the Auto Scaling group, call the UpdateAutoScalingGroup API and set the minimum size and desired capacity of the Auto Scaling group to zero.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        force_delete(bool, optional): Specifies that the group is to be deleted along with all instances associated with the group, without waiting for all instances to be terminated. This parameter also deletes any outstanding lifecycle actions associated with the group. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.auto_scaling.group.delete(
                ctx, auto_scaling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.auto_scaling.group.delete auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="delete_auto_scaling_group",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "ForceDelete": force_delete,
        },
    )


async def describe_all(
    hub,
    ctx,
    auto_scaling_group_names: List = None,
    next_token: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the Auto Scaling groups in the account and Region. This operation returns information about instances in Auto Scaling groups. To retrieve information about the instances in a warm pool, you must call the DescribeWarmPool API.

    Args:
        auto_scaling_group_names(List, optional): The names of the Auto Scaling groups. By default, you can only specify up to 50 names. You can optionally increase this limit using the MaxRecords parameter. If you omit this parameter, all Auto Scaling groups are described. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        max_records(int, optional): The maximum number of items to return with this call. The default value is 50 and the maximum value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.auto_scaling.group.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.auto_scaling.group.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_auto_scaling_groups",
        op_kwargs={
            "AutoScalingGroupNames": auto_scaling_group_names,
            "NextToken": next_token,
            "MaxRecords": max_records,
        },
    )


async def update(
    hub,
    ctx,
    auto_scaling_group_name: str,
    launch_configuration_name: str = None,
    launch_template: Dict = None,
    mixed_instances_policy: Dict = None,
    min_size: int = None,
    max_size: int = None,
    desired_capacity: int = None,
    default_cooldown: int = None,
    availability_zones: List = None,
    health_check_type: str = None,
    health_check_grace_period: int = None,
    placement_group: str = None,
    vpc_zone_identifier: str = None,
    termination_policies: List = None,
    new_instances_protected_from_scale_in: bool = None,
    service_linked_role_arn: str = None,
    max_instance_lifetime: int = None,
    capacity_rebalance: bool = None,
    context: str = None,
) -> None:
    r"""
    **Autogenerated function**

     We strongly recommend that all Auto Scaling groups use launch templates to ensure full functionality for Amazon EC2 Auto Scaling and Amazon EC2.  Updates the configuration for the specified Auto Scaling group. To update an Auto Scaling group, specify the name of the group and the parameter that you want to change. Any parameters that you don't specify are not changed by this update request. The new settings take effect on any scaling activities after this call returns.  If you associate a new launch configuration or template with an Auto Scaling group, all new instances will get the updated configuration. Existing instances continue to run with the configuration that they were originally launched with. When you update a group to specify a mixed instances policy instead of a launch configuration or template, existing instances may be replaced to match the new purchasing options that you specified in the policy. For example, if the group currently has 100% On-Demand capacity and the policy specifies 50% Spot capacity, this means that half of your instances will be gradually terminated and relaunched as Spot Instances. When replacing instances, Amazon EC2 Auto Scaling launches new instances before terminating the old ones, so that updating your group does not compromise the performance or availability of your application. Note the following about changing DesiredCapacity, MaxSize, or MinSize:   If a scale-in activity occurs as a result of a new DesiredCapacity value that is lower than the current size of the group, the Auto Scaling group uses its termination policy to determine which instances to terminate.   If you specify a new value for MinSize without specifying a value for DesiredCapacity, and the new MinSize is larger than the current size of the group, this sets the group's DesiredCapacity to the new MinSize value.   If you specify a new value for MaxSize without specifying a value for DesiredCapacity, and the new MaxSize is smaller than the current size of the group, this sets the group's DesiredCapacity to the new MaxSize value.   To see which parameters have been set, call the DescribeAutoScalingGroups API. To view the scaling policies for an Auto Scaling group, call the DescribePolicies API. If the group has scaling policies, you can update them by calling the PutScalingPolicy API.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        launch_configuration_name(str, optional): The name of the launch configuration. If you specify LaunchConfigurationName in your update request, you can't specify LaunchTemplate or MixedInstancesPolicy. Defaults to None.
        launch_template(Dict, optional): The launch template and version to use to specify the updates. If you specify LaunchTemplate in your update request, you can't specify LaunchConfigurationName or MixedInstancesPolicy. Defaults to None.
        mixed_instances_policy(Dict, optional): An embedded object that specifies a mixed instances policy. When you make changes to an existing policy, all optional properties are left unchanged if not specified. For more information, see Auto Scaling groups with multiple instance types and purchase options in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        min_size(int, optional): The minimum size of the Auto Scaling group. Defaults to None.
        max_size(int, optional): The maximum size of the Auto Scaling group.  With a mixed instances policy that uses instance weighting, Amazon EC2 Auto Scaling may need to go above MaxSize to meet your capacity requirements. In this event, Amazon EC2 Auto Scaling will never go above MaxSize by more than your largest instance weight (weights that define how many units each instance contributes to the desired capacity of the group). . Defaults to None.
        desired_capacity(int, optional): The desired capacity is the initial capacity of the Auto Scaling group after this operation completes and the capacity it attempts to maintain. This number must be greater than or equal to the minimum size of the group and less than or equal to the maximum size of the group. Defaults to None.
        default_cooldown(int, optional): The amount of time, in seconds, after a scaling activity completes before another scaling activity can start. The default value is 300. This setting applies when using simple scaling policies, but not when using other scaling policies or scheduled scaling. For more information, see Scaling cooldowns for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        availability_zones(List, optional): One or more Availability Zones for the group. Defaults to None.
        health_check_type(str, optional): The service to use for the health checks. The valid values are EC2 and ELB. If you configure an Auto Scaling group to use ELB health checks, it considers the instance unhealthy if it fails either the EC2 status checks or the load balancer health checks. Defaults to None.
        health_check_grace_period(int, optional): The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before checking the health status of an EC2 instance that has come into service. The default value is 0. For more information, see Health check grace period in the Amazon EC2 Auto Scaling User Guide. Conditional: Required if you are adding an ELB health check. Defaults to None.
        placement_group(str, optional): The name of an existing placement group into which to launch your instances, if any. A placement group is a logical grouping of instances within a single Availability Zone. You cannot specify multiple Availability Zones and a placement group. For more information, see Placement Groups in the Amazon EC2 User Guide for Linux Instances. Defaults to None.
        vpc_zone_identifier(str, optional): A comma-separated list of subnet IDs for a virtual private cloud (VPC). If you specify VPCZoneIdentifier with AvailabilityZones, the subnets that you specify for this parameter must reside in those Availability Zones. Defaults to None.
        termination_policies(List, optional): A policy or a list of policies that are used to select the instances to terminate. The policies are executed in the order that you list them. For more information, see Controlling which Auto Scaling instances terminate during scale in in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        new_instances_protected_from_scale_in(bool, optional): Indicates whether newly launched instances are protected from termination by Amazon EC2 Auto Scaling when scaling in. For more information about preventing instances from terminating on scale in, see Instance scale-in protection in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        service_linked_role_arn(str, optional): The Amazon Resource Name (ARN) of the service-linked role that the Auto Scaling group uses to call other Amazon Web Services on your behalf. For more information, see Service-linked roles in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        max_instance_lifetime(int, optional): The maximum amount of time, in seconds, that an instance can be in service. The default is null. If specified, the value must be either 0 or a number equal to or greater than 86,400 seconds (1 day). To clear a previously set value, specify a new value of 0. For more information, see Replacing Auto Scaling instances based on maximum instance lifetime in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        capacity_rebalance(bool, optional): Enables or disables Capacity Rebalancing. For more information, see Amazon EC2 Auto Scaling Capacity Rebalancing in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        context(str, optional): Reserved. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.auto_scaling.group.update(
                ctx, auto_scaling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.auto_scaling.group.update auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="update_auto_scaling_group",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "LaunchConfigurationName": launch_configuration_name,
            "LaunchTemplate": launch_template,
            "MixedInstancesPolicy": mixed_instances_policy,
            "MinSize": min_size,
            "MaxSize": max_size,
            "DesiredCapacity": desired_capacity,
            "DefaultCooldown": default_cooldown,
            "AvailabilityZones": availability_zones,
            "HealthCheckType": health_check_type,
            "HealthCheckGracePeriod": health_check_grace_period,
            "PlacementGroup": placement_group,
            "VPCZoneIdentifier": vpc_zone_identifier,
            "TerminationPolicies": termination_policies,
            "NewInstancesProtectedFromScaleIn": new_instances_protected_from_scale_in,
            "ServiceLinkedRoleARN": service_linked_role_arn,
            "MaxInstanceLifetime": max_instance_lifetime,
            "CapacityRebalance": capacity_rebalance,
            "Context": context,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def restore(
    hub,
    ctx,
    db_cluster_identifier: str,
    engine: str,
    master_username: str,
    master_user_password: str,
    source_engine: str,
    source_engine_version: str,
    s3_bucket_name: str,
    s3_ingestion_role_arn: str,
    availability_zones: List = None,
    backup_retention_period: int = None,
    character_set_name: str = None,
    database_name: str = None,
    db_cluster_parameter_group_name: str = None,
    vpc_security_group_ids: List = None,
    db_subnet_group_name: str = None,
    engine_version: str = None,
    port: int = None,
    option_group_name: str = None,
    preferred_backup_window: str = None,
    preferred_maintenance_window: str = None,
    tags: List = None,
    storage_encrypted: bool = None,
    kms_key_id: str = None,
    enable_iam_database_authentication: bool = None,
    s3_prefix: str = None,
    backtrack_window: int = None,
    enable_cloudwatch_logs_exports: List = None,
    deletion_protection: bool = None,
    copy_tags_to_snapshot: bool = None,
    domain: str = None,
    domain_iam_role_name: str = None,
) -> Dict:
    r'''
    **Autogenerated function**

    Creates an Amazon Aurora DB cluster from MySQL data stored in an Amazon S3 bucket. Amazon RDS must be authorized to access the Amazon S3 bucket and the data must be created using the Percona XtraBackup utility as described in  Migrating Data from MySQL by Using an Amazon S3 Bucket in the Amazon Aurora User Guide.  This action only restores the DB cluster, not the DB instances for that DB cluster. You must invoke the CreateDBInstance action to create DB instances for the restored DB cluster, specifying the identifier of the restored DB cluster in DBClusterIdentifier. You can create DB instances only after the RestoreDBClusterFromS3 action has completed and the DB cluster is available.  For more information on Amazon Aurora, see  What Is Amazon Aurora? in the Amazon Aurora User Guide.   This action only applies to Aurora DB clusters. The source DB engine must be MySQL.

    Args:
        availability_zones(List, optional): A list of Availability Zones (AZs) where instances in the restored DB cluster can be created. Defaults to None.
        backup_retention_period(int, optional): The number of days for which automated backups of the restored DB cluster are retained. You must specify a minimum value of 1. Default: 1 Constraints:   Must be a value from 1 to 35  . Defaults to None.
        character_set_name(str, optional): A value that indicates that the restored DB cluster should be associated with the specified CharacterSet. Defaults to None.
        database_name(str, optional): The database name for the restored DB cluster. Defaults to None.
        db_cluster_identifier(str): The name of the DB cluster to create from the source data in the Amazon S3 bucket. This parameter isn't case-sensitive. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens.   First character must be a letter.   Can't end with a hyphen or contain two consecutive hyphens.   Example: my-cluster1 .
        db_cluster_parameter_group_name(str, optional): The name of the DB cluster parameter group to associate with the restored DB cluster. If this argument is omitted, default.aurora5.6 is used.  Constraints:   If supplied, must match the name of an existing DBClusterParameterGroup.  . Defaults to None.
        vpc_security_group_ids(List, optional): A list of EC2 VPC security groups to associate with the restored DB cluster. Defaults to None.
        db_subnet_group_name(str, optional): A DB subnet group to associate with the restored DB cluster. Constraints: If supplied, must match the name of an existing DBSubnetGroup.  Example: mySubnetgroup . Defaults to None.
        engine(str): The name of the database engine to be used for this DB cluster. Valid Values: aurora (for MySQL 5.6-compatible Aurora), aurora-mysql (for MySQL 5.7-compatible Aurora), and aurora-postgresql .
        engine_version(str, optional): The version number of the database engine to use. To list all of the available engine versions for aurora (for MySQL 5.6-compatible Aurora), use the following command:  aws rds describe-db-engine-versions --engine aurora --query "DBEngineVersions[].EngineVersion"  To list all of the available engine versions for aurora-mysql (for MySQL 5.7-compatible Aurora), use the following command:  aws rds describe-db-engine-versions --engine aurora-mysql --query "DBEngineVersions[].EngineVersion"  To list all of the available engine versions for aurora-postgresql, use the following command:  aws rds describe-db-engine-versions --engine aurora-postgresql --query "DBEngineVersions[].EngineVersion"   Aurora MySQL  Example: 5.6.10a, 5.6.mysql_aurora.1.19.2, 5.7.12, 5.7.mysql_aurora.2.04.5   Aurora PostgreSQL  Example: 9.6.3, 10.7 . Defaults to None.
        port(int, optional): The port number on which the instances in the restored DB cluster accept connections.  Default: 3306 . Defaults to None.
        master_username(str): The name of the master user for the restored DB cluster. Constraints:   Must be 1 to 16 letters or numbers.   First character must be a letter.   Can't be a reserved word for the chosen database engine.  .
        master_user_password(str): The password for the master database user. This password can contain any printable ASCII character except "/", """, or "@". Constraints: Must contain from 8 to 41 characters.
        option_group_name(str, optional): A value that indicates that the restored DB cluster should be associated with the specified option group. Permanent options can't be removed from an option group. An option group can't be removed from a DB cluster once it is associated with a DB cluster. Defaults to None.
        preferred_backup_window(str, optional): The daily time range during which automated backups are created if automated backups are enabled using the BackupRetentionPeriod parameter.  The default is a 30-minute window selected at random from an 8-hour block of time for each Amazon Web Services Region. To view the time blocks available, see  Backup window in the Amazon Aurora User Guide.  Constraints:   Must be in the format hh24:mi-hh24:mi.   Must be in Universal Coordinated Time (UTC).   Must not conflict with the preferred maintenance window.   Must be at least 30 minutes.  . Defaults to None.
        preferred_maintenance_window(str, optional): The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC). Format: ddd:hh24:mi-ddd:hh24:mi  The default is a 30-minute window selected at random from an 8-hour block of time for each Amazon Web Services Region, occurring on a random day of the week. To see the time blocks available, see  Adjusting the Preferred Maintenance Window in the Amazon Aurora User Guide.  Valid Days: Mon, Tue, Wed, Thu, Fri, Sat, Sun. Constraints: Minimum 30-minute window. Defaults to None.
        tags(List, optional): A list of tags. For more information, see Tagging Amazon RDS Resources in the Amazon RDS User Guide. . Defaults to None.
        storage_encrypted(bool, optional): A value that indicates whether the restored DB cluster is encrypted. Defaults to None.
        kms_key_id(str, optional): The Amazon Web Services KMS key identifier for an encrypted DB cluster. The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the Amazon Web Services KMS customer master key (CMK). To use a CMK in a different Amazon Web Services account, specify the key ARN or alias ARN. If the StorageEncrypted parameter is enabled, and you do not specify a value for the KmsKeyId parameter, then Amazon RDS will use your default CMK. There is a default CMK for your Amazon Web Services account. Your Amazon Web Services account has a different default CMK for each Amazon Web Services Region. Defaults to None.
        enable_iam_database_authentication(bool, optional): A value that indicates whether to enable mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts. By default, mapping is disabled. For more information, see  IAM Database Authentication in the Amazon Aurora User Guide. . Defaults to None.
        source_engine(str): The identifier for the database engine that was backed up to create the files stored in the Amazon S3 bucket.  Valid values: mysql .
        source_engine_version(str): The version of the database that the backup files were created from. MySQL versions 5.5, 5.6, and 5.7 are supported.  Example: 5.6.40, 5.7.28 .
        s3_bucket_name(str): The name of the Amazon S3 bucket that contains the data used to create the Amazon Aurora DB cluster.
        s3_prefix(str, optional): The prefix for all of the file names that contain the data used to create the Amazon Aurora DB cluster. If you do not specify a SourceS3Prefix value, then the Amazon Aurora DB cluster is created by using all of the files in the Amazon S3 bucket. Defaults to None.
        s3_ingestion_role_arn(str): The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that authorizes Amazon RDS to access the Amazon S3 bucket on your behalf.
        backtrack_window(int, optional): The target backtrack window, in seconds. To disable backtracking, set this value to 0.  Currently, Backtrack is only supported for Aurora MySQL DB clusters.  Default: 0 Constraints:   If specified, this value must be set to a number from 0 to 259,200 (72 hours).  . Defaults to None.
        enable_cloudwatch_logs_exports(List, optional): The list of logs that the restored DB cluster is to export to CloudWatch Logs. The values in the list depend on the DB engine being used. For more information, see Publishing Database Logs to Amazon CloudWatch Logs in the Amazon Aurora User Guide. Defaults to None.
        deletion_protection(bool, optional): A value that indicates whether the DB cluster has deletion protection enabled. The database can't be deleted when deletion protection is enabled. By default, deletion protection is disabled. . Defaults to None.
        copy_tags_to_snapshot(bool, optional): A value that indicates whether to copy all tags from the restored DB cluster to snapshots of the restored DB cluster. The default is not to copy them. Defaults to None.
        domain(str, optional): Specify the Active Directory directory ID to restore the DB cluster in. The domain must be created prior to this operation.   For Amazon Aurora DB clusters, Amazon RDS can use Kerberos Authentication to authenticate users that connect to the DB cluster. For more information, see Kerberos Authentication in the Amazon Aurora User Guide. . Defaults to None.
        domain_iam_role_name(str, optional): Specify the name of the IAM role to be used when making API calls to the Directory Service. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.cluster.from_.s3.restore(
                ctx,
                db_cluster_identifier=value,
                engine=value,
                master_username=value,
                master_user_password=value,
                source_engine=value,
                source_engine_version=value,
                s3_bucket_name=value,
                s3_ingestion_role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.cluster.from_.s3.restore db_cluster_identifier=value, engine=value, master_username=value, master_user_password=value, source_engine=value, source_engine_version=value, s3_bucket_name=value, s3_ingestion_role_arn=value
    '''
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="restore_db_cluster_from_s3",
        op_kwargs={
            "AvailabilityZones": availability_zones,
            "BackupRetentionPeriod": backup_retention_period,
            "CharacterSetName": character_set_name,
            "DatabaseName": database_name,
            "DBClusterIdentifier": db_cluster_identifier,
            "DBClusterParameterGroupName": db_cluster_parameter_group_name,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "DBSubnetGroupName": db_subnet_group_name,
            "Engine": engine,
            "EngineVersion": engine_version,
            "Port": port,
            "MasterUsername": master_username,
            "MasterUserPassword": master_user_password,
            "OptionGroupName": option_group_name,
            "PreferredBackupWindow": preferred_backup_window,
            "PreferredMaintenanceWindow": preferred_maintenance_window,
            "Tags": tags,
            "StorageEncrypted": storage_encrypted,
            "KmsKeyId": kms_key_id,
            "EnableIAMDatabaseAuthentication": enable_iam_database_authentication,
            "SourceEngine": source_engine,
            "SourceEngineVersion": source_engine_version,
            "S3BucketName": s3_bucket_name,
            "S3Prefix": s3_prefix,
            "S3IngestionRoleArn": s3_ingestion_role_arn,
            "BacktrackWindow": backtrack_window,
            "EnableCloudwatchLogsExports": enable_cloudwatch_logs_exports,
            "DeletionProtection": deletion_protection,
            "CopyTagsToSnapshot": copy_tags_to_snapshot,
            "Domain": domain,
            "DomainIAMRoleName": domain_iam_role_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, event_source_name: str, next_token: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    An SaaS partner can use this operation to display the AWS account ID that a particular partner event source name is associated with. This operation is not used by AWS customers.

    Args:
        event_source_name(str): The name of the partner event source to display account information about.
        next_token(str, optional): The token returned by a previous call to this operation. Specifying this retrieves the next set of results. Defaults to None.
        limit(int, optional): Specifying this limits the number of results returned by this operation. The operation also returns a NextToken which you can use in a subsequent operation to retrieve the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.partner_event.source.account.list_all(
                ctx, event_source_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.partner_event.source.account.list_all event_source_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="list_partner_event_source_accounts",
        op_kwargs={
            "EventSourceName": event_source_name,
            "NextToken": next_token,
            "Limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    accept_language: str = None,
    product_id: str = None,
    product_name: str = None,
    provisioning_artifact_id: str = None,
    provisioning_artifact_name: str = None,
    path_id: str = None,
    path_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the configuration required to provision the specified product using the specified provisioning artifact. If the output contains a TagOption key with an empty list of values, there is a TagOption conflict for that key. The end user cannot take action to fix the conflict, and launch is not blocked. In subsequent calls to ProvisionProduct, do not include conflicted TagOption keys as tags, or this causes the error "Parameter validation failed: Missing required parameter in Tags[N]:Value". Tag the provisioned product with the value sc-tagoption-conflict-portfolioId-productId.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        product_id(str, optional): The product identifier. You must provide the product name or ID, but not both. Defaults to None.
        product_name(str, optional): The name of the product. You must provide the name or ID, but not both. Defaults to None.
        provisioning_artifact_id(str, optional): The identifier of the provisioning artifact. You must provide the name or ID, but not both. Defaults to None.
        provisioning_artifact_name(str, optional): The name of the provisioning artifact. You must provide the name or ID, but not both. Defaults to None.
        path_id(str, optional): The path identifier of the product. This value is optional if the product has a default path, and required if the product has more than one path. To list the paths for a product, use ListLaunchPaths. You must provide the name or ID, but not both. Defaults to None.
        path_name(str, optional): The name of the path. You must provide the name or ID, but not both. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.provisioning.parameter.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.provisioning.parameter.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_provisioning_parameters",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "ProductId": product_id,
            "ProductName": product_name,
            "ProvisioningArtifactId": provisioning_artifact_id,
            "ProvisioningArtifactName": provisioning_artifact_name,
            "PathId": path_id,
            "PathName": path_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, policy_name: str = None) -> None:
    r"""
    **Autogenerated function**

    Deletes a resource policy from this account. This revokes the access of the identities in that policy to put log events to this account.

    Args:
        policy_name(str, optional): The name of the policy to be revoked. This parameter is required. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.resource_policy.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.resource_policy.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="delete_resource_policy",
        op_kwargs={"policyName": policy_name},
    )


async def describe_all(hub, ctx, next_token: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the resource policies in this account.

    Args:
        next_token(str, optional): The token for the next set of items to return. The token expires after 24 hours. Defaults to None.
        limit(int, optional): The maximum number of resource policies to be displayed with one call of this API. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.resource_policy.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.resource_policy.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="describe_resource_policies",
        op_kwargs={"nextToken": next_token, "limit": limit},
    )


async def put(hub, ctx, policy_name: str = None, policy_document: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates a resource policy allowing other AWS services to put log events to this account, such as Amazon Route 53. An account can have up to 10 resource policies per AWS Region.

    Args:
        policy_name(str, optional): Name of the new policy. This parameter is required. Defaults to None.
        policy_document(str, optional): Details of the new policy, including the identity of the principal that is enabled to put logs to this account. This is formatted as a JSON string. This parameter is required. The following example creates a resource policy enabling the Route 53 service to put DNS query logs in to the specified log group. Replace "logArn" with the ARN of your CloudWatch Logs resource, such as a log group or log stream.  { "Version": "2012-10-17", "Statement": [ { "Sid": "Route53LogsToCloudWatchLogs", "Effect": "Allow", "Principal": { "Service": [ "route53.amazonaws.com" ] }, "Action":"logs:PutLogEvents", "Resource": "logArn" } ] }  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.resource_policy.put(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.resource_policy.put
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="put_resource_policy",
        op_kwargs={"policyName": policy_name, "policyDocument": policy_document},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def acknowledge(hub, ctx, job_id: str, nonce: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specified job and whether that job has been received by the job worker. Used for custom actions only.

    Args:
        job_id(str): The unique system-generated ID of the job for which you want to confirm receipt.
        nonce(str): A system-generated random number that AWS CodePipeline uses to ensure that the job is being worked on by only one job worker. Get this number from the response of the PollForJobs request that returned this job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.job.init.acknowledge(
                ctx, job_id=value, nonce=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.job.init.acknowledge job_id=value, nonce=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="acknowledge_job",
        op_kwargs={"jobId": job_id, "nonce": nonce},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    virtual_cluster_id: str,
    type_: str,
    release_label: str,
    execution_role_arn: str,
    certificate_arn: str,
    client_token: str,
    configuration_overrides: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a managed endpoint. A managed endpoint is a gateway that connects EMR Studio to Amazon EMR on EKS so that EMR Studio can communicate with your virtual cluster.

    Args:
        name(str): The name of the managed endpoint.
        virtual_cluster_id(str): The ID of the virtual cluster for which a managed endpoint is created.
        type_(str): The type of the managed endpoint.
        release_label(str): The Amazon EMR release version.
        execution_role_arn(str): The ARN of the execution role.
        certificate_arn(str): The certificate ARN of the managed endpoint.
        configuration_overrides(Dict, optional): The configuration settings that will be used to override existing configurations. Defaults to None.
        client_token(str): The client idempotency token for this create call.
        tags(Dict, optional): The tags of the managed endpoint. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr_container.managed_endpoint.create(
                ctx,
                name=value,
                virtual_cluster_id=value,
                type_=value,
                release_label=value,
                execution_role_arn=value,
                certificate_arn=value,
                client_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr_container.managed_endpoint.create name=value, virtual_cluster_id=value, type_=value, release_label=value, execution_role_arn=value, certificate_arn=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr-containers",
        operation="create_managed_endpoint",
        op_kwargs={
            "name": name,
            "virtualClusterId": virtual_cluster_id,
            "type": type_,
            "releaseLabel": release_label,
            "executionRoleArn": execution_role_arn,
            "certificateArn": certificate_arn,
            "configurationOverrides": configuration_overrides,
            "clientToken": client_token,
            "tags": tags,
        },
    )


async def delete(hub, ctx, id_: str, virtual_cluster_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a managed endpoint. A managed endpoint is a gateway that connects EMR Studio to Amazon EMR on EKS so that EMR Studio can communicate with your virtual cluster.

    Args:
        id_(str): The ID of the managed endpoint.
        virtual_cluster_id(str): The ID of the endpoint's virtual cluster.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr_container.managed_endpoint.delete(
                ctx, id_=value, virtual_cluster_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr_container.managed_endpoint.delete id_=value, virtual_cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr-containers",
        operation="delete_managed_endpoint",
        op_kwargs={"id": id_, "virtualClusterId": virtual_cluster_id},
    )


async def describe(hub, ctx, id_: str, virtual_cluster_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Displays detailed information about a managed endpoint. A managed endpoint is a gateway that connects EMR Studio to Amazon EMR on EKS so that EMR Studio can communicate with your virtual cluster.

    Args:
        id_(str): This output displays ID of the managed endpoint.
        virtual_cluster_id(str): The ID of the endpoint's virtual cluster.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr_container.managed_endpoint.describe(
                ctx, id_=value, virtual_cluster_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr_container.managed_endpoint.describe id_=value, virtual_cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr-containers",
        operation="describe_managed_endpoint",
        op_kwargs={"id": id_, "virtualClusterId": virtual_cluster_id},
    )


async def list_all(
    hub,
    ctx,
    virtual_cluster_id: str,
    created_before: str = None,
    created_after: str = None,
    types: List = None,
    states: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists managed endpoints based on a set of parameters. A managed endpoint is a gateway that connects EMR Studio to Amazon EMR on EKS so that EMR Studio can communicate with your virtual cluster.

    Args:
        virtual_cluster_id(str): The ID of the virtual cluster.
        created_before(str, optional): The date and time before which the endpoints are created. Defaults to None.
        created_after(str, optional):  The date and time after which the endpoints are created. Defaults to None.
        types(List, optional): The types of the managed endpoints. Defaults to None.
        states(List, optional): The states of the managed endpoints. Defaults to None.
        max_results(int, optional): The maximum number of managed endpoints that can be listed. Defaults to None.
        next_token(str, optional):  The token for the next set of managed endpoints to return. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr_container.managed_endpoint.list_all(
                ctx, virtual_cluster_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr_container.managed_endpoint.list_all virtual_cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr-containers",
        operation="list_managed_endpoints",
        op_kwargs={
            "virtualClusterId": virtual_cluster_id,
            "createdBefore": created_before,
            "createdAfter": created_after,
            "types": types,
            "states": states,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub,
    ctx,
    cluster_identifier: str = None,
    table_restore_request_id: str = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the status of one or more table restore requests made using the RestoreTableFromClusterSnapshot API action. If you don't specify a value for the TableRestoreRequestId parameter, then DescribeTableRestoreStatus returns the status of all table restore requests ordered by the date and time of the request in ascending order. Otherwise DescribeTableRestoreStatus returns the status of the table specified by TableRestoreRequestId.

    Args:
        cluster_identifier(str, optional): The Amazon Redshift cluster that the table is being restored to. Defaults to None.
        table_restore_request_id(str, optional): The identifier of the table restore request to return status for. If you don't specify a TableRestoreRequestId value, then DescribeTableRestoreStatus returns the status of all in-progress table restore requests. Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous DescribeTableRestoreStatus request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by the MaxRecords parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.table.restore_status.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.table.restore_status.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_table_restore_status",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "TableRestoreRequestId": table_restore_request_id,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, cluster_id: str, availability_zone: str, ip_address: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new hardware security module (HSM) in the specified AWS CloudHSM cluster.

    Args:
        cluster_id(str): The identifier (ID) of the HSM's cluster. To find the cluster ID, use DescribeClusters.
        availability_zone(str): The Availability Zone where you are creating the HSM. To find the cluster's Availability Zones, use DescribeClusters.
        ip_address(str, optional): The HSM's IP address. If you specify an IP address, use an available address from the subnet that maps to the Availability Zone where you are creating the HSM. If you don't specify an IP address, one is chosen for you from that subnet. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsmv2.hsm.create(
                ctx, cluster_id=value, availability_zone=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsmv2.hsm.create cluster_id=value, availability_zone=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsmv2",
        operation="create_hsm",
        op_kwargs={
            "ClusterId": cluster_id,
            "AvailabilityZone": availability_zone,
            "IpAddress": ip_address,
        },
    )


async def delete(
    hub,
    ctx,
    cluster_id: str,
    hsm_id: str = None,
    eni_id: str = None,
    eni_ip: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified HSM. To specify an HSM, you can use its identifier (ID), the IP address of the HSM's elastic network interface (ENI), or the ID of the HSM's ENI. You need to specify only one of these values. To find these values, use DescribeClusters.

    Args:
        cluster_id(str): The identifier (ID) of the cluster that contains the HSM that you are deleting.
        hsm_id(str, optional): The identifier (ID) of the HSM that you are deleting. Defaults to None.
        eni_id(str, optional): The identifier (ID) of the elastic network interface (ENI) of the HSM that you are deleting. Defaults to None.
        eni_ip(str, optional): The IP address of the elastic network interface (ENI) of the HSM that you are deleting. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsmv2.hsm.delete(ctx, cluster_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsmv2.hsm.delete cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsmv2",
        operation="delete_hsm",
        op_kwargs={
            "ClusterId": cluster_id,
            "HsmId": hsm_id,
            "EniId": eni_id,
            "EniIp": eni_ip,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def get_all(hub, ctx, identity_pool_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the roles for an identity pool. You must use AWS Developer credentials to call this API.

    Args:
        identity_pool_id(str): An identity pool ID in the format REGION:GUID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_identity.identity.pool.role.get_all(
                ctx, identity_pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_identity.identity.pool.role.get_all identity_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-identity",
        operation="get_identity_pool_roles",
        op_kwargs={"IdentityPoolId": identity_pool_id},
    )


async def set_(
    hub, ctx, identity_pool_id: str, roles: Dict, role_mappings: Dict = None
) -> None:
    r"""
    **Autogenerated function**

    Sets the roles for an identity pool. These roles are used when making calls to GetCredentialsForIdentity action. You must use AWS Developer credentials to call this API.

    Args:
        identity_pool_id(str): An identity pool ID in the format REGION:GUID.
        roles(Dict): The map of roles associated with this pool. For a given role, the key will be either "authenticated" or "unauthenticated" and the value will be the Role ARN.
        role_mappings(Dict, optional): How users for a specific identity provider are to mapped to roles. This is a string to RoleMapping object map. The string identifies the identity provider, for example, "graph.facebook.com" or "cognito-idp.us-east-1.amazonaws.com/us-east-1_abcdefghi:app_client_id". Up to 25 rules can be specified per identity provider. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_identity.identity.pool.role.set(
                ctx, identity_pool_id=value, roles=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_identity.identity.pool.role.set identity_pool_id=value, roles=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-identity",
        operation="set_identity_pool_roles",
        op_kwargs={
            "IdentityPoolId": identity_pool_id,
            "Roles": roles,
            "RoleMappings": role_mappings,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "type"


async def describe_all(hub, ctx, policy_type_names: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified load balancer policy types or all load balancer policy types. The description of each type indicates how it can be used. For example, some policies can be used only with layer 7 listeners, some policies can be used only with layer 4 listeners, and some policies can be used only with your EC2 instances. You can use CreateLoadBalancerPolicy to create a policy configuration for any of these policy types. Then, depending on the policy type, use either SetLoadBalancerPoliciesOfListener or SetLoadBalancerPoliciesForBackendServer to set the policy.

    Args:
        policy_type_names(List, optional): The names of the policy types. If no names are specified, describes all policy types defined by Elastic Load Balancing. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.policy.type_.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.policy.type.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="describe_load_balancer_policy_types",
        op_kwargs={"PolicyTypeNames": policy_type_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "pattern_set"


async def create(hub, ctx, name: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Creates a RegexPatternSet. You then use UpdateRegexPatternSet to specify the regular expression (regex) pattern that you want AWS WAF to search for, such as B[a@]dB[o0]t. You can then configure AWS WAF to reject those requests. To create and configure a RegexPatternSet, perform the following steps:   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a CreateRegexPatternSet request.   Submit a CreateRegexPatternSet request.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateRegexPatternSet request.   Submit an UpdateRegexPatternSet request to specify the string that you want AWS WAF to watch for.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        name(str): A friendly name or description of the RegexPatternSet. You can't change Name after you create a RegexPatternSet.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.regex.pattern_set_.create(
                ctx, name=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.regex.pattern_set.create name=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="create_regex_pattern_set",
        op_kwargs={"Name": name, "ChangeToken": change_token},
    )


async def delete(hub, ctx, regex_pattern_set_id: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Permanently deletes a RegexPatternSet. You can't delete a RegexPatternSet if it's still used in any RegexMatchSet or if the RegexPatternSet is not empty.

    Args:
        regex_pattern_set_id(str): The RegexPatternSetId of the RegexPatternSet that you want to delete. RegexPatternSetId is returned by CreateRegexPatternSet and by ListRegexPatternSets.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.regex.pattern_set_.delete(
                ctx, regex_pattern_set_id=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.regex.pattern_set.delete regex_pattern_set_id=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="delete_regex_pattern_set",
        op_kwargs={
            "RegexPatternSetId": regex_pattern_set_id,
            "ChangeToken": change_token,
        },
    )


async def get(hub, ctx, regex_pattern_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the RegexPatternSet specified by RegexPatternSetId.

    Args:
        regex_pattern_set_id(str): The RegexPatternSetId of the RegexPatternSet that you want to get. RegexPatternSetId is returned by CreateRegexPatternSet and by ListRegexPatternSets.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.regex.pattern_set_.get(
                ctx, regex_pattern_set_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.regex.pattern_set.get regex_pattern_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="get_regex_pattern_set",
        op_kwargs={"RegexPatternSetId": regex_pattern_set_id},
    )


async def list_all(hub, ctx, next_marker: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of RegexPatternSetSummary objects.

    Args:
        next_marker(str, optional): If you specify a value for Limit and you have more RegexPatternSet objects than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of RegexPatternSet objects. For the second and subsequent ListRegexPatternSets requests, specify the value of NextMarker from the previous response to get information about another batch of RegexPatternSet objects. Defaults to None.
        limit(int, optional): Specifies the number of RegexPatternSet objects that you want AWS WAF to return for this request. If you have more RegexPatternSet objects than the number you specify for Limit, the response includes a NextMarker value that you can use to get another batch of RegexPatternSet objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.regex.pattern_set_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.regex.pattern_set.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="list_regex_pattern_sets",
        op_kwargs={"NextMarker": next_marker, "Limit": limit},
    )


async def update(
    hub, ctx, regex_pattern_set_id: str, updates: List, change_token: str
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Inserts or deletes RegexPatternString objects in a RegexPatternSet. For each RegexPatternString object, you specify the following values:    Whether to insert or delete the RegexPatternString.   The regular expression pattern that you want to insert or delete. For more information, see RegexPatternSet.     For example, you can create a RegexPatternString such as B[a@]dB[o0]t. AWS WAF will match this RegexPatternString to:   BadBot   BadB0t   B@dBot   B@dB0t   To create and configure a RegexPatternSet, perform the following steps:   Create a RegexPatternSet. For more information, see CreateRegexPatternSet.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateRegexPatternSet request.   Submit an UpdateRegexPatternSet request to specify the regular expression pattern that you want AWS WAF to watch for.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        regex_pattern_set_id(str): The RegexPatternSetId of the RegexPatternSet that you want to update. RegexPatternSetId is returned by CreateRegexPatternSet and by ListRegexPatternSets.
        updates(List): An array of RegexPatternSetUpdate objects that you want to insert into or delete from a RegexPatternSet.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.regex.pattern_set_.update(
                ctx, regex_pattern_set_id=value, updates=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.regex.pattern_set.update regex_pattern_set_id=value, updates=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="update_regex_pattern_set",
        op_kwargs={
            "RegexPatternSetId": regex_pattern_set_id,
            "Updates": updates,
            "ChangeToken": change_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "for_object_lambda"


async def delete(hub, ctx, account_id: str, name: str) -> None:
    r"""
    **Autogenerated function**

    Removes the resource policy for an Object Lambda Access Point. The following actions are related to DeleteAccessPointPolicyForObjectLambda:    GetAccessPointPolicyForObjectLambda     PutAccessPointPolicyForObjectLambda

    Args:
        account_id(str): The account ID for the account that owns the specified Object Lambda Access Point.
        name(str): The name of the Object Lambda Access Point you want to delete the policy for.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.access_point.policy.for_object_lambda_.delete(
                ctx, account_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.access_point.policy.for_object_lambda.delete account_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="delete_access_point_policy_for_object_lambda",
        op_kwargs={"AccountId": account_id, "Name": name},
    )


async def get(hub, ctx, account_id: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the resource policy for an Object Lambda Access Point. The following actions are related to GetAccessPointPolicyForObjectLambda:    DeleteAccessPointPolicyForObjectLambda     PutAccessPointPolicyForObjectLambda

    Args:
        account_id(str): The account ID for the account that owns the specified Object Lambda Access Point.
        name(str): The name of the Object Lambda Access Point.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.access_point.policy.for_object_lambda_.get(
                ctx, account_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.access_point.policy.for_object_lambda.get account_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="get_access_point_policy_for_object_lambda",
        op_kwargs={"AccountId": account_id, "Name": name},
    )


async def put(hub, ctx, account_id: str, name: str, policy: str) -> None:
    r"""
    **Autogenerated function**

    Creates or replaces resource policy for an Object Lambda Access Point. For an example policy, see Creating Object Lambda Access Points in the Amazon S3 User Guide. The following actions are related to PutAccessPointPolicyForObjectLambda:    DeleteAccessPointPolicyForObjectLambda     GetAccessPointPolicyForObjectLambda

    Args:
        account_id(str): The account ID for the account that owns the specified Object Lambda Access Point.
        name(str): The name of the Object Lambda Access Point.
        policy(str): Object Lambda Access Point resource policy document.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.access_point.policy.for_object_lambda_.put(
                ctx, account_id=value, name=value, policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.access_point.policy.for_object_lambda.put account_id=value, name=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="put_access_point_policy_for_object_lambda",
        op_kwargs={"AccountId": account_id, "Name": name, "Policy": policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, task_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels an existing Amazon FSx for Lustre data repository task if that task is in either the PENDING or EXECUTING state. When you cancel a task, Amazon FSx does the following.   Any files that FSx has already exported are not reverted.   FSx continues to export any files that are "in-flight" when the cancel operation is received.   FSx does not export any files that have not yet been exported.

    Args:
        task_id(str): Specifies the data repository task to cancel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.data_repository_task.cancel(ctx, task_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.data_repository_task.cancel task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="cancel_data_repository_task",
        op_kwargs={"TaskId": task_id},
    )


async def create(
    hub,
    ctx,
    type_: str,
    file_system_id: str,
    report: Dict,
    paths: List = None,
    client_request_token: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon FSx for Lustre data repository task. You use data repository tasks to perform bulk operations between your Amazon FSx file system and its linked data repository. An example of a data repository task is exporting any data and metadata changes, including POSIX metadata, to files, directories, and symbolic links (symlinks) from your FSx file system to its linked data repository. A CreateDataRepositoryTask operation will fail if a data repository is not linked to the FSx file system. To learn more about data repository tasks, see Data Repository Tasks. To learn more about linking a data repository to your file system, see Linking your file system to an S3 bucket.

    Args:
        type_(str): Specifies the type of data repository task to create.
        paths(List, optional): (Optional) The path or paths on the Amazon FSx file system to use when the data repository task is processed. The default path is the file system root directory. The paths you provide need to be relative to the mount point of the file system. If the mount point is /mnt/fsx and /mnt/fsx/path1 is a directory or file on the file system you want to export, then the path to provide is path1. If a path that you provide isn't valid, the task fails. Defaults to None.
        file_system_id(str): The globally unique ID of the file system, assigned by Amazon FSx.
        report(Dict): Defines whether or not Amazon FSx provides a CompletionReport once the task has completed. A CompletionReport provides a detailed report on the files that Amazon FSx processed that meet the criteria specified by the Scope parameter. For more information, see Working with Task Completion Reports.
        client_request_token(str, optional): (Optional) An idempotency token for resource creation, in a string of up to 64 ASCII characters. This token is automatically filled on your behalf when you use the AWS Command Line Interface (AWS CLI) or an AWS SDK. Defaults to None.
        tags(List, optional): A list of Tag values, with a maximum of 50 elements. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.data_repository_task.create(
                ctx, type_=value, file_system_id=value, report=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.data_repository_task.create type_=value, file_system_id=value, report=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="create_data_repository_task",
        op_kwargs={
            "Type": type_,
            "Paths": paths,
            "FileSystemId": file_system_id,
            "Report": report,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )


async def describe_all(
    hub,
    ctx,
    task_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the description of specific Amazon FSx for Lustre data repository tasks, if one or more TaskIds values are provided in the request, or if filters are used in the request. You can use filters to narrow the response to include just tasks for specific file systems, or tasks in a specific lifecycle state. Otherwise, it returns all data repository tasks owned by your AWS account in the AWS Region of the endpoint that you're calling. When retrieving all tasks, you can paginate the response by using the optional MaxResults parameter to limit the number of tasks returned in a response. If more tasks remain, Amazon FSx returns a NextToken value in the response. In this case, send a later request with the NextToken request parameter set to the value of NextToken from the last response.

    Args:
        task_ids(List, optional): (Optional) IDs of the tasks whose descriptions you want to retrieve (String). Defaults to None.
        filters(List, optional): (Optional) You can use filters to narrow the DescribeDataRepositoryTasks response to include just tasks for specific file systems, or tasks in a specific lifecycle state. Defaults to None.
        max_results(int, optional): The maximum number of resources to return in the response. This value must be an integer greater than zero. Defaults to None.
        next_token(str, optional): (Optional) Opaque pagination token returned from a previous operation (String). If present, this token indicates from what point you can continue processing the request, where the previous NextToken value left off. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.data_repository_task.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.data_repository_task.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="describe_data_repository_tasks",
        op_kwargs={
            "TaskIds": task_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(
    hub,
    ctx,
    workbook_id: str,
    table_id: str,
    row_ids: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The ListTableRows API allows you to retrieve a list of all the rows in a table in a workbook.

    Args:
        workbook_id(str): The ID of the workbook that contains the table whose rows are being retrieved.  If a workbook with the specified id could not be found, this API throws ResourceNotFoundException. .
        table_id(str): The ID of the table whose rows are being retrieved.  If a table with the specified id could not be found, this API throws ResourceNotFoundException. .
        row_ids(List, optional):  This parameter is optional. If one or more row ids are specified in this list, then only the specified row ids are returned in the result. If no row ids are specified here, then all the rows in the table are returned. . Defaults to None.
        max_results(int, optional): The maximum number of rows to return in each page of the results. Defaults to None.
        next_token(str, optional):  This parameter is optional. If a nextToken is not specified, the API returns the first page of data.   Pagination tokens expire after 1 hour. If you use a token that was returned more than an hour back, the API will throw ValidationException. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.honeycode.table.row.list_all(
                ctx, workbook_id=value, table_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.honeycode.table.row.list_all workbook_id=value, table_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="honeycode",
        operation="list_table_rows",
        op_kwargs={
            "workbookId": workbook_id,
            "tableId": table_id,
            "rowIds": row_ids,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def query(
    hub,
    ctx,
    workbook_id: str,
    table_id: str,
    filter_formula: Dict,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The QueryTableRows API allows you to use a filter formula to query for specific rows in a table.

    Args:
        workbook_id(str): The ID of the workbook whose table rows are being queried.  If a workbook with the specified id could not be found, this API throws ResourceNotFoundException. .
        table_id(str): The ID of the table whose rows are being queried.  If a table with the specified id could not be found, this API throws ResourceNotFoundException. .
        filter_formula(Dict): An object that represents a filter formula along with the id of the context row under which the filter function needs to evaluate.
        max_results(int, optional): The maximum number of rows to return in each page of the results. Defaults to None.
        next_token(str, optional):  This parameter is optional. If a nextToken is not specified, the API returns the first page of data.   Pagination tokens expire after 1 hour. If you use a token that was returned more than an hour back, the API will throw ValidationException. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.honeycode.table.row.query(
                ctx, workbook_id=value, table_id=value, filter_formula=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.honeycode.table.row.query workbook_id=value, table_id=value, filter_formula=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="honeycode",
        operation="query_table_rows",
        op_kwargs={
            "workbookId": workbook_id,
            "tableId": table_id,
            "filterFormula": filter_formula,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    workload_name: str,
    description: str,
    environment: str,
    review_owner: str,
    lenses: List,
    client_request_token: str,
    account_ids: List = None,
    aws_regions: List = None,
    non_aws_regions: List = None,
    pillar_priorities: List = None,
    architectural_design: str = None,
    industry_type: str = None,
    industry: str = None,
    notes: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a new workload. The owner of a workload can share the workload with other AWS accounts and IAM users in the same AWS Region. Only the owner of a workload can delete it. For more information, see Defining a Workload in the AWS Well-Architected Tool User Guide.

    Args:
        workload_name(str): The name of the workload. The name must be unique within an account within a Region. Spaces and capitalization are ignored when checking for uniqueness.
        description(str): The description for the workload.
        environment(str): The environment for the workload.
        account_ids(List, optional): The list of AWS account IDs associated with the workload. Defaults to None.
        aws_regions(List, optional): The list of AWS Regions associated with the workload, for example, us-east-2, or ca-central-1. Defaults to None.
        non_aws_regions(List, optional):  The list of non-AWS Regions associated with the workload. Defaults to None.
        pillar_priorities(List, optional): The priorities of the pillars, which are used to order items in the improvement plan. Each pillar is represented by its PillarReviewSummary$PillarId. Defaults to None.
        architectural_design(str, optional): The URL of the architectural design for the workload. Defaults to None.
        review_owner(str): The review owner of the workload. The name, email address, or identifier for the primary group or individual that owns the workload review process.
        industry_type(str, optional): The industry type for the workload. If specified, must be one of the following:    Agriculture     Automobile     Defense     Design and Engineering     Digital Advertising     Education     Environmental Protection     Financial Services     Gaming     General Public Services     Healthcare     Hospitality     InfoTech     Justice and Public Safety     Life Sciences     Manufacturing     Media & Entertainment     Mining & Resources     Oil & Gas     Power & Utilities     Professional Services     Real Estate & Construction     Retail & Wholesale     Social Protection     Telecommunications     Travel, Transportation & Logistics     Other   . Defaults to None.
        industry(str, optional): The industry for the workload. Defaults to None.
        lenses(List): The list of lenses associated with the workload. Each lens is identified by its LensSummary$LensAlias.
        notes(str, optional): The notes associated with the workload. Defaults to None.
        client_request_token(str): A unique case-sensitive string used to ensure that this request is idempotent (executes only once). You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after it has completed successfully, the result of the original request is returned.   This token is listed as required, however, if you do not specify it, the AWS SDKs automatically generate one for you. If you are not using the AWS SDK or the AWS CLI, you must provide this token or the request will fail. .
        tags(Dict, optional): The tags to be associated with the workload. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.workload.init.create(
                ctx,
                workload_name=value,
                description=value,
                environment=value,
                review_owner=value,
                lenses=value,
                client_request_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.workload.init.create workload_name=value, description=value, environment=value, review_owner=value, lenses=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="create_workload",
        op_kwargs={
            "WorkloadName": workload_name,
            "Description": description,
            "Environment": environment,
            "AccountIds": account_ids,
            "AwsRegions": aws_regions,
            "NonAwsRegions": non_aws_regions,
            "PillarPriorities": pillar_priorities,
            "ArchitecturalDesign": architectural_design,
            "ReviewOwner": review_owner,
            "IndustryType": industry_type,
            "Industry": industry,
            "Lenses": lenses,
            "Notes": notes,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, workload_id: str, client_request_token: str) -> None:
    r"""
    **Autogenerated function**

    Delete an existing workload.

    Args:
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        client_request_token(str): A unique case-sensitive string used to ensure that this request is idempotent (executes only once). You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after it has completed successfully, the result of the original request is returned.   This token is listed as required, however, if you do not specify it, the AWS SDKs automatically generate one for you. If you are not using the AWS SDK or the AWS CLI, you must provide this token or the request will fail. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.workload.init.delete(
                ctx, workload_id=value, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.workload.init.delete workload_id=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="delete_workload",
        op_kwargs={
            "WorkloadId": workload_id,
            "ClientRequestToken": client_request_token,
        },
    )


async def get(hub, ctx, workload_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Get an existing workload.

    Args:
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.workload.init.get(ctx, workload_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.workload.init.get workload_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="get_workload",
        op_kwargs={"WorkloadId": workload_id},
    )


async def list_all(
    hub,
    ctx,
    workload_name_prefix: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List workloads. Paginated.

    Args:
        workload_name_prefix(str, optional): An optional string added to the beginning of each workload name returned in the results. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for this request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.workload.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.workload.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="list_workloads",
        op_kwargs={
            "WorkloadNamePrefix": workload_name_prefix,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    workload_id: str,
    workload_name: str = None,
    description: str = None,
    environment: str = None,
    account_ids: List = None,
    aws_regions: List = None,
    non_aws_regions: List = None,
    pillar_priorities: List = None,
    architectural_design: str = None,
    review_owner: str = None,
    is_review_owner_update_acknowledged: bool = None,
    industry_type: str = None,
    industry: str = None,
    notes: str = None,
    improvement_status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update an existing workload.

    Args:
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        workload_name(str, optional): The name of the workload. The name must be unique within an account within a Region. Spaces and capitalization are ignored when checking for uniqueness. Defaults to None.
        description(str, optional): The description for the workload. Defaults to None.
        environment(str, optional): The environment for the workload. Defaults to None.
        account_ids(List, optional): The list of AWS account IDs associated with the workload. Defaults to None.
        aws_regions(List, optional): The list of AWS Regions associated with the workload, for example, us-east-2, or ca-central-1. Defaults to None.
        non_aws_regions(List, optional):  The list of non-AWS Regions associated with the workload. Defaults to None.
        pillar_priorities(List, optional): The priorities of the pillars, which are used to order items in the improvement plan. Each pillar is represented by its PillarReviewSummary$PillarId. Defaults to None.
        architectural_design(str, optional): The URL of the architectural design for the workload. Defaults to None.
        review_owner(str, optional): The review owner of the workload. The name, email address, or identifier for the primary group or individual that owns the workload review process. Defaults to None.
        is_review_owner_update_acknowledged(bool, optional): Flag indicating whether the workload owner has acknowledged that the Review owner field is required. If a Review owner is not added to the workload within 60 days of acknowledgement, access to the workload is restricted until an owner is added. Defaults to None.
        industry_type(str, optional): The industry type for the workload. If specified, must be one of the following:    Agriculture     Automobile     Defense     Design and Engineering     Digital Advertising     Education     Environmental Protection     Financial Services     Gaming     General Public Services     Healthcare     Hospitality     InfoTech     Justice and Public Safety     Life Sciences     Manufacturing     Media & Entertainment     Mining & Resources     Oil & Gas     Power & Utilities     Professional Services     Real Estate & Construction     Retail & Wholesale     Social Protection     Telecommunications     Travel, Transportation & Logistics     Other   . Defaults to None.
        industry(str, optional): The industry for the workload. Defaults to None.
        notes(str, optional): The notes associated with the workload. Defaults to None.
        improvement_status(str, optional): The improvement status for a workload. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.workload.init.update(ctx, workload_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.workload.init.update workload_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="update_workload",
        op_kwargs={
            "WorkloadId": workload_id,
            "WorkloadName": workload_name,
            "Description": description,
            "Environment": environment,
            "AccountIds": account_ids,
            "AwsRegions": aws_regions,
            "NonAwsRegions": non_aws_regions,
            "PillarPriorities": pillar_priorities,
            "ArchitecturalDesign": architectural_design,
            "ReviewOwner": review_owner,
            "IsReviewOwnerUpdateAcknowledged": is_review_owner_update_acknowledged,
            "IndustryType": industry_type,
            "Industry": industry,
            "Notes": notes,
            "ImprovementStatus": improvement_status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, filters: Dict, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of the events emitted by the resources that are evaluated by DevOps Guru. You can use filters to specify which events are returned.

    Args:
        filters(Dict):  A ListEventsFilters object used to specify which events to return. .
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.event.list_all(ctx, filters=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.event.list_all filters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="list_events",
        op_kwargs={
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, policy_source_arn: str, policy_input_list: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of all of the context keys referenced in all the IAM policies that are attached to the specified IAM entity. The entity can be an IAM user, group, or role. If you specify a user, then the request also includes all of the policies attached to groups that the user is a member of. You can optionally include a list of one or more additional policies, specified as strings. If you want to include only a list of policies by string, use GetContextKeysForCustomPolicy instead.  Note: This operation discloses information about the permissions granted to other users. If you do not want users to see other user's permissions, then consider allowing them to use GetContextKeysForCustomPolicy instead. Context keys are variables maintained by Amazon Web Services and its services that provide details about the context of an API query request. Context keys can be evaluated by testing against a value in an IAM policy. Use GetContextKeysForPrincipalPolicy to understand what key names and values you must supply when you call SimulatePrincipalPolicy.

    Args:
        policy_source_arn(str): The ARN of a user, group, or role whose policies contain the context keys that you want listed. If you specify a user, the list includes context keys that are found in all policies that are attached to the user. The list also includes all groups that the user is a member of. If you pick a group or a role, then it includes only those context keys that are found in policies attached to that entity. Note that all parameters are shown in unencoded form here for clarity, but must be URL encoded to be included as a part of a real HTML request. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
        policy_input_list(List, optional): An optional list of additional policies for which you want the list of context keys that are referenced. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.context_keys_for_.principal_policy.get(
                ctx, policy_source_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.context_keys_for_.principal_policy.get policy_source_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_context_keys_for_principal_policy",
        op_kwargs={
            "PolicySourceArn": policy_source_arn,
            "PolicyInputList": policy_input_list,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(
    hub,
    ctx,
    pipeline_name: str,
    stage_name: str,
    action_name: str,
    action_revision: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides information to AWS CodePipeline about new revisions to a source.

    Args:
        pipeline_name(str): The name of the pipeline that starts processing the revision to the source.
        stage_name(str): The name of the stage that contains the action that acts on the revision.
        action_name(str): The name of the action that processes the revision.
        action_revision(Dict): Represents information about the version (or revision) of an action.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.action.revision.put(
                ctx, pipeline_name=value, stage_name=value, action_name=value, action_revision=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.action.revision.put pipeline_name=value, stage_name=value, action_name=value, action_revision=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="put_action_revision",
        op_kwargs={
            "pipelineName": pipeline_name,
            "stageName": stage_name,
            "actionName": action_name,
            "actionRevision": action_revision,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "change_set"


async def generate(hub, ctx, app_id: str = None, changeset_format: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Generates a target change set for a currently launched stack and writes it to an Amazon S3 object in the customer’s Amazon S3 bucket.

    Args:
        app_id(str, optional): The ID of the application associated with the change set. Defaults to None.
        changeset_format(str, optional): The format for the change set. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.change_set_.generate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.change_set.generate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="generate_change_set",
        op_kwargs={"appId": app_id, "changesetFormat": changeset_format},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, stream_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides a summarized description of the specified Kinesis data stream without the shard list. The information returned includes the stream name, Amazon Resource Name (ARN), status, record retention period, approximate creation time, monitoring, encryption details, and open shard count.   DescribeStreamSummary has a limit of 20 transactions per second per account.

    Args:
        stream_name(str): The name of the stream to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.stream.summary.describe(ctx, stream_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.stream.summary.describe stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="describe_stream_summary",
        op_kwargs={"StreamName": stream_name},
    )
